package com.akamai.ampdemoui;

import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.ProgressBar;
import android.widget.RelativeLayout;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.ui.listeners.IMediaPlayerControllerListener;
import com.akamai.ui.media.MediaPlayerController;


public class MainActivity extends Activity implements IMediaPlayerControllerListener {

    private final String TAG = MainActivity.class.getSimpleName();

    // Video Player container object
    private VideoPlayerContainer mVideoPlayerContainer;

    // Video Player object
    private VideoPlayerView mVideoPlayer;

    // Control bar component
    private MediaPlayerController mMediaPlayerController;

    // Progress bar control
    private ProgressBar mProgressBar;

    // Seek Button
    private Button mBtnSeek;

    // Android SDK License
    private static final String ANDROID_SDK_LICENSE = "eSwrM-aDq2lv2d35NMXiigENPdd1RFUKfL7LJbTfOfjP_MleTGEZLEJYXIqNVJ8dVN4R1eoj-VZ22Up0XCK_Wg==";

    // Media Asset url
    //private static final String MEDIA_ASSET_URL = "http://multiplatform-f.akamaihd.net/i/multi/april11/hdworld/hdworld_,512x288_450_b,640x360_700_b,768x432_1000_b,1024x576_1400_m,1280x720_1900_m,1280x720_2500_m,1280x720_3500_m,.mp4.csmil/master.m3u8";
    private static final String MEDIA_ASSET_URL = "http://areenahdworld-vh.akamaihd.net/i/world/fc/fc109000d87499d670a0e09e54fb9c87_,1021952,151552,666624,405504,.mp4.csmil/master.m3u8?hdnea=st=1413463685~exp=1444999685~acl=/i/*~hmac=f70cabf56fadf1a6c34dda249604c27f9682120f54ba943071f522962b1d82b5";

    // Keep current fullscreen mode
    private boolean mFullScreenMode = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // Initialize Progress Bar
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);

        // Initialize and configure the VideoPlayerContainer and VideoPlayerView
        mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);
        mVideoPlayer = mVideoPlayerContainer.getVideoPlayer();
        mVideoPlayer.setLicense(ANDROID_SDK_LICENSE);

        // Initialize UI Control bar
        mMediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);

        // Set the VideoPlayer object to the MediaController
        mMediaPlayerController.setVideoPlayerView(mVideoPlayer);

        // Set this object to listen SDK events and start playing the url
        mVideoPlayer.setProgressBarControl(mProgressBar);

        // Listen to control bar events
        mMediaPlayerController.setEventsListener(this);

        // Play Url
        mVideoPlayer.playUrl(MEDIA_ASSET_URL);

        checkDeviceOrientation();

        Log.i(TAG, "VERSION: "+mVideoPlayer.VERSION);


        mBtnSeek = (Button) findViewById(R.id.btnSeek);
        mBtnSeek.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                mVideoPlayer.seek(10 + mVideoPlayer.getTimePosition(), 0);
            }
        });
    }

    private void checkDeviceOrientation() {
        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE)
        {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);
            mFullScreenMode = true;
        }
        else if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT)
        {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_FULLSCREEN);
            mFullScreenMode = false;
        }
    }

    @Override
    protected void onResume()
    {
        if(mVideoPlayer != null)
            mVideoPlayer.onResume();

        super.onResume();
    }

    @Override
    protected void onPause()
    {
        if(mVideoPlayer != null)
            mVideoPlayer.onPause();

        super.onPause();
    }


    @Override
    protected void onDestroy()
    {
        mVideoPlayer.stop();
        mVideoPlayer.onDestroy();
        super.onDestroy();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);

        // Checks the orientation of the screen
        if (newConfig.orientation == Configuration.ORIENTATION_LANDSCAPE)
        {
            setFullScreenMode(true);

            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);
        }
        else if (newConfig.orientation == Configuration.ORIENTATION_PORTRAIT)
        {
            setFullScreenMode(false);

            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);
        }

    }

    private void setFullScreenMode(boolean fullscreen)
    {
        if(fullscreen == mFullScreenMode)
            return;

        // Checks the orientation of the screen
        if (fullscreen)
        {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);

            RelativeLayout playerContainer = (RelativeLayout) findViewById(R.id.playerContainer);

            LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(FrameLayout.LayoutParams.FILL_PARENT, FrameLayout.LayoutParams.FILL_PARENT);
            playerContainer.setLayoutParams(params);

            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);

            mVideoPlayerContainer.requestLayout();
        }
        else if (!fullscreen)
        {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);

            RelativeLayout playerContainer = (RelativeLayout) findViewById(R.id.playerContainer);
            LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(FrameLayout.LayoutParams.FILL_PARENT, (int)getResources().getDimension(R.dimen.player_height));
            playerContainer.setLayoutParams(params);

            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_FULLSCREEN);

            mVideoPlayerContainer.requestLayout();
        }

        mFullScreenMode = fullscreen;
    }

    @Override
    public void onButtonClicked(int arg0) {

        if(arg0 == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_FULLSCREEN)
            setFullScreenMode(!mFullScreenMode);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
